<?php

namespace Drupal\order\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\RevisionLogInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining Product entities.
 *
 * @ingroup order
 */
interface ProductInterface extends ContentEntityInterface, RevisionLogInterface, EntityChangedInterface, EntityOwnerInterface {

  /**
   * Gets the Product name.
   *
   * @return string
   *   Name of the Product.
   */
  public function getName();

  /**
   * Sets the Product name.
   *
   * @param string $name
   *   The Product name.
   *
   * @return \Drupal\order\Entity\ProductInterface
   *   The called Product entity.
   */
  public function setName($name);

  /**
   * Gets the Product creation timestamp.
   *
   * @return int
   *   Creation timestamp of the Product.
   */
  public function getCreatedTime();

  /**
   * Sets the Product creation timestamp.
   *
   * @param int $timestamp
   *   The Product creation timestamp.
   *
   * @return \Drupal\order\Entity\ProductInterface
   *   The called Product entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the Product published status indicator.
   *
   * Unpublished Product are only visible to restricted users.
   *
   * @return bool
   *   TRUE if the Product is published.
   */
  public function isPublished();

  /**
   * Sets the published status of a Product.
   *
   * @param bool $published
   *   TRUE to set this Product to published, FALSE to set it to unpublished.
   *
   * @return \Drupal\order\Entity\ProductInterface
   *   The called Product entity.
   */
  public function setPublished($published);

  /**
   * Gets the Product revision creation timestamp.
   *
   * @return int
   *   The UNIX timestamp of when this revision was created.
   */
  public function getRevisionCreationTime();

  /**
   * Sets the Product revision creation timestamp.
   *
   * @param int $timestamp
   *   The UNIX timestamp of when this revision was created.
   *
   * @return \Drupal\order\Entity\ProductInterface
   *   The called Product entity.
   */
  public function setRevisionCreationTime($timestamp);

  /**
   * Gets the Product revision author.
   *
   * @return \Drupal\user\UserInterface
   *   The user entity for the revision author.
   */
  public function getRevisionUser();

  /**
   * Sets the Product revision author.
   *
   * @param int $uid
   *   The user ID of the revision author.
   *
   * @return \Drupal\order\Entity\ProductInterface
   *   The called Product entity.
   */
  public function setRevisionUserId($uid);

  /**
   * Gets the parent entity of the paragraph.
   *
   * Preserves language context with translated entities.
   *
   * @return \Drupal\Core\Entity\ContentEntityInterface
   *   The parent entity.
   */
  public function getParentEntity();

  /**
   * Set the parent entity of the paragraph.
   *
   * @param \Drupal\Core\Entity\ContentEntityInterface $parent
   *   The parent entity.
   * @param string $parent_field_name
   *   The parent field name.
   *
   * @return $this
   */
  public function setParentEntity(ContentEntityInterface $parent, $parent_field_name);

}
