<?php

namespace Drupal\order\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\Core\Config\Entity\ConfigEntityInterface;

/**
 * Defines the Store entity.
 *
 * @ConfigEntityType(
 *   id = "store",
 *   label = @Translation("Store"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\order\StoreListBuilder",
 *     "form" = {
 *       "add" = "Drupal\order\Form\StoreForm",
 *       "edit" = "Drupal\order\Form\StoreForm",
 *       "delete" = "Drupal\order\Form\StoreDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\AdminHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "store",
 *   admin_permission = "administer site configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   links = {
 *     "canonical" = "/admin/configuration/store/store/{store}",
 *     "add-form" = "/admin/configuration/store/store/add",
 *     "edit-form" = "/admin/configuration/store/store/{store}/edit",
 *     "delete-form" = "/admin/configuration/store/store/{store}/delete",
 *     "collection" = "/admin/configuration/store/store"
 *   }
 * )
 */
class Store extends ConfigEntityBase implements ConfigEntityInterface {

  /**
   * The Store ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The Store UUID.
   *
   * @var uuid
   */
  protected $uuid;

  /**
   * The Store label.
   *
   * @var string
   */
  protected $label;

  /**
   * The base path of the store.
   *
   * @var string
   */
  protected $base_path;

  /**
   * The order bundle(s) to use.
   *
   * @var mixed
   */
  protected $order_bundle;

  /**
   * The process plugins to execute at order completion.
   *
   * @var mixed
   */
  protected $process_plugins;

  /**
   * The order state transitions.
   *
   * @var mixed
   */
  protected $order_states;

  /**
   * Label overrides.
   *
   * @var mixed
   */
  protected $label_overrides;

  /**
   * Settings.
   *
   * @var mixed
   */
  protected $settings;

  /**
   * Get label override default values.
   */
  public function getOverrides() {
    $overrides = $this->get('label_overrides');

    $defaults = [
      'process_name' => 'Order',
      'process_name_plural' => 'Orders',
      'order_title' => 'View order',
      'empty_order' => 'Empty order',
      'view_order_button' => 'View order',
      'add_button' => 'Add to order',
      'added_button' => 'Added',
      'added_text' => 'Added to order',
      'added_text_link' => '1',
      'remove_text' => 'Remove from order',
      'continue_text' => 'Continue shopping',
      'update_button' => 'Update',
      'update_order_button' => 'Update order',
      'update_order_message' => 'Order has been updated',
      'checkout_title' => 'Complete order',
      'checkout_text' => 'To complete your order, fill out the form below and submit.',
      'checkout_button' => 'Submit order',
    ];

    if (empty($overrides)) {
      $overrides = $defaults;
    }
    else {
      $overrides = array_merge($defaults, array_filter($overrides));
    }
    return $overrides;
  }

}
