<?php

namespace Drupal\order\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\order\Entity\Order;

/**
 * Base form configuration for checkout process.
 */
abstract class CheckoutFormBase extends FormBase implements FormInterface {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $build_info = $form_state->getBuildInfo();
    if ($build_info['args'] && $build_info['args'][0] instanceof Order) {
      $this->order = $build_info['args'][0];
    }

    $form['first_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('First name'),
    ];

    $form['last_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Last name'),
    ];

    $form['address'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Address'),
    ];
    $form['city'] = [
      '#type' => 'textfield',
      '#title' => $this->t('City'),
    ];
    $form['state'] = [
      '#type' => 'select',
      '#title' => $this->t('state'),
      '#options' => $this->getStates(),
      '#default_value' => 'MN',
    ];
    $form['zip'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Zip code'),
    ];
    $form['email'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Email'),
    ];
    $form['phone'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Phone'),
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
      '#button_type' => 'primary',
    ];

    $form['#submit'][] = '::processValues';
    $form['#submit'][] = '\Drupal\order\Controller\OrderController::OrderCheckoutSubmitForm';

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Handle form submission.
    // self::processValues($form, $form_state);.
  }

  /**
   * Process Values from the form.
   */
  public static function processValues(array &$form, FormStateInterface &$form_state) {
    $contact = [];
    $address = [];
    $data = [];

    // Map form values to the standard format.
    $contact['first_name'] = $form_state->getValue('first_name');
    $contact['last_name'] = $form_state->getValue('last_name');
    $contact['phone'] = $form_state->getValue('phone');
    $contact['email'] = $form_state->getValue('email');

    // Map form values to the standard format.
    $address['address_1'] = $form_state->getValue('address');
    $address['address_2'] = NULL;
    $address['locality'] = $form_state->getValue('city');
    $address['administrative_area'] = $form_state->getValue('state');
    $address['postal_code'] = $form_state->getValue('zip');
    $address['country'] = 'US';

    $data['contact'] = $contact;
    $data['address'] = $address;

    // Add the normalized data to the $form_state.
    $form_state->set('processedCheckoutData', $data);
  }

  /**
   * Array of states.
   */
  public function getStates() {
    return [
      'AL' => 'ALABAMA',
      'AK' => 'ALASKA',
      'AS' => 'AMERICAN SAMOA',
      'AZ' => 'ARIZONA',
      'AR' => 'ARKANSAS',
      'CA' => 'CALIFORNIA',
      'CO' => 'COLORADO',
      'CT' => 'CONNECTICUT',
      'DE' => 'DELAWARE',
      'DC' => 'DISTRICT OF COLUMBIA',
      'FM' => 'FEDERATED STATES OF MICRONESIA',
      'FL' => 'FLORIDA',
      'GA' => 'GEORGIA',
      'GU' => 'GUAM GU',
      'HI' => 'HAWAII',
      'ID' => 'IDAHO',
      'IL' => 'ILLINOIS',
      'IN' => 'INDIANA',
      'IA' => 'IOWA',
      'KS' => 'KANSAS',
      'KY' => 'KENTUCKY',
      'LA' => 'LOUISIANA',
      'ME' => 'MAINE',
      'MH' => 'MARSHALL ISLANDS',
      'MD' => 'MARYLAND',
      'MA' => 'MASSACHUSETTS',
      'MI' => 'MICHIGAN',
      'MN' => 'MINNESOTA',
      'MS' => 'MISSISSIPPI',
      'MO' => 'MISSOURI',
      'MT' => 'MONTANA',
      'NE' => 'NEBRASKA',
      'NV' => 'NEVADA',
      'NH' => 'NEW HAMPSHIRE',
      'NJ' => 'NEW JERSEY',
      'NM' => 'NEW MEXICO',
      'NY' => 'NEW YORK',
      'NC' => 'NORTH CAROLINA',
      'ND' => 'NORTH DAKOTA',
      'MP' => 'NORTHERN MARIANA ISLANDS',
      'OH' => 'OHIO',
      'OK' => 'OKLAHOMA',
      'OR' => 'OREGON',
      'PW' => 'PALAU',
      'PA' => 'PENNSYLVANIA',
      'PR' => 'PUERTO RICO',
      'RI' => 'RHODE ISLAND',
      'SC' => 'SOUTH CAROLINA',
      'SD' => 'SOUTH DAKOTA',
      'TN' => 'TENNESSEE',
      'TX' => 'TEXAS',
      'UT' => 'UTAH',
      'VT' => 'VERMONT',
      'VI' => 'VIRGIN ISLANDS',
      'VA' => 'VIRGINIA',
      'WA' => 'WASHINGTON',
      'WV' => 'WEST VIRGINIA',
      'WI' => 'WISCONSIN',
      'WY' => 'WYOMING',
      'AE' => 'ARMED FORCES AFRICA \ CANADA \ EUROPE \ MIDDLE EAST',
      'AA' => 'ARMED FORCES AMERICA (EXCEPT CANADA)',
      'AP' => 'ARMED FORCES PACIFIC',
    ];
  }

}
