<?php

namespace Drupal\order\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\order\Controller\OrderController;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Url;

/**
 * Provides a 'Basic Cart Count' block.
 *
 * @Block(
 *   id = "order_view_button",
 *   admin_label = @Translation("Order: View button")
 * )
 */
class OrderViewButtonBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * Entity Type Manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The order controller.
   *
   * @var \Drupal\order\Controller\OrderController
   */
  protected $orderController;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('order.controller')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, EntityTypeManagerInterface $entity_type_manager, OrderController $order_controller) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->entityTypeManager = $entity_type_manager;
    $this->orderController = $order_controller;
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = $this->getConfiguration();
    $store = $this->entityTypeManager->getStorage('store')->load($config['store']);
    $labels = $store->getOverrides();
    $view_text = $labels['view_order_button'];
    $view_link = Url::fromRoute('order.viewCart', ['store' => $store->id()])->toString();
    $render = [
      '#theme' => 'order_view_button_block',
      '#count' => $this->orderController->orderCount($store),
      '#view_link' => $view_link,
      '#view_text' => $view_text,
      '#cache' => ['max-age' => 0],
    ];
    return $render;
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);

    $config = $this->getConfiguration();

    $stores = $this->entityTypeManager->getStorage('store')->loadMultiple();
    $options = [];
    foreach ($stores as $store) {
      $options[$store->id()] = $store->label();
    }

    $form['store'] = [
      '#type' => 'select',
      '#options' => $options,
      '#title' => $this->t('Store'),
      '#description' => $this->t('Store to display the order count of.'),
      '#default_value' => isset($config['store']) ? $config['store'] : '',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    parent::blockSubmit($form, $form_state);
    $values = $form_state->getValues();
    $this->configuration['store'] = $values['store'];
  }

}
