<?php

namespace Drupal\order\Plugin;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;

/**
 * Provides an Checkout plugin manager.
 *
 * @see \Drupal\order\Annotation\Checkout
 * @see \Drupal\order\Plugin\CheckoutInterface
 * @see plugin_api
 */
class CheckoutManager extends DefaultPluginManager {

  /**
   * Constructs a CheckoutManager object.
   *
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler to invoke the alter hook with.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct(
      'Plugin/Order/Checkout',
      $namespaces,
      $module_handler,
      'Drupal\order\Plugin\CheckoutInterface',
      'Drupal\order\Annotation\Checkout'
    );
    $this->alterInfo('checkout_info');
    $this->setCacheBackend($cache_backend, 'checkout_info_plugins');
  }

}
