<?php

namespace Drupal\order\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\inline_entity_form\Plugin\Field\FieldWidget\InlineEntityFormComplex;

/**
 * Complex inline widget.
 *
 * @FieldWidget(
 *   id = "product_widget",
 *   label = @Translation("Product widget"),
 *   field_types = {
 *     "product_reference"
 *   },
 *   multiple_values = true
 * )
 */
class ProductWidget extends InlineEntityFormComplex {

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $element = parent::settingsForm($form, $form_state);
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = parent::settingsSummary();
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element = parent::formElement($items, $delta, $element, $form, $form_state);

    $host_entity = $items->getEntity();

    $parent_entity = [
      'id' => $host_entity->id(),
      'type' => $host_entity->getEntityTypeId(),
      'field_name' => $this->fieldDefinition->getName(),
    ];

    $form_state->set([
      'inline_entity_form',
      $this->getIefId(),
      'parent',
    ], $parent_entity);

    return $element;
  }

  /**
   * Marks created/edited entity with "needs save" flag.
   */
  public static function submitSaveEntity($entity_form, FormStateInterface $form_state) {
    $ief_id = $entity_form['#ief_id'];
    /** @var \Drupal\Core\Entity\EntityInterface $entity */
    $entity = $entity_form['#entity'];

    $parent = $form_state->get(['inline_entity_form', $ief_id, 'parent']);
    $entity->set('parent_type', $parent['type']);
    $entity->set('parent_id', $parent['id']);
    $entity->set('parent_field_name', $parent['field_name']);

    if (in_array($entity_form['#op'], ['add', 'duplicate'])) {
      // Determine the correct weight of the new element.
      $weight = 0;
      $entities = $form_state->get(['inline_entity_form', $ief_id, 'entities']);
      if (!empty($entities)) {
        $weight = max(array_keys($entities)) + 1;
      }

      // Add the entity to form state, mark it for saving, and close the form.
      $entities[] = [
        'entity' => $entity,
        'weight' => $weight,
        'form' => NULL,
        'needs_save' => TRUE,
      ];
      $form_state->set(['inline_entity_form', $ief_id, 'entities'], $entities);
    }
    else {
      $delta = $entity_form['#ief_row_delta'];
      $entities = $form_state->get(['inline_entity_form', $ief_id, 'entities']);
      $entities[$delta]['entity'] = $entity;
      $entities[$delta]['needs_save'] = TRUE;
      $form_state->set(['inline_entity_form', $ief_id, 'entities'], $entities);
    }
  }

}
