<?php

namespace Drupal\order\Plugin\Order\Process;

use Drupal\Core\Form\FormStateInterface;
use Drupal\order\Plugin\OrderProcessPluginBase;
use Drupal\order\Entity\Order;

/**
 * A Process plugin which emails the order result.
 *
 * @package Drupal\order\Plugin\Order\Process
 *
 * @OrderProcess(
 *   id = "email",
 *   label = "Email Order data",
 * )
 */
class EmailProcess extends OrderProcessPluginBase {

  /**
   * Default settings.
   */
  public function defaultSettings() {
    // Return the site's email address as a default value.
  }

  /**
   * The process plugin settings form.
   */
  public function settingsForm(&$form, FormStateInterface $form_state, $store = NULL) {
    $config = $this->getConfig();
    $settings = [];

    if (!empty($config) && isset($store)) {
      $settings = $config->get($store);
    }

    $form['order']['process'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Email process plugin settings'),
      '#tree' => TRUE,
    ];
    $form['order']['process']['email'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Email address'),
      '#description' => $this->t('The email address to send order data to upon submission'),
      '#default_value' => !empty($settings) ? $settings['email'] : '',
    ];
  }

  /**
   * Submit method for the process plugin settings form.
   */
  public function settingsSubmit(&$form, FormStateInterface $form_state) {
    $settings = $form_state->getValue('process');
    $store = $form_state->getValue('id');
    $this->setConfig($store, $settings);
  }

  /**
   * Get the plugin configuration.
   */
  public function getConfig() {
    $config = $this->config->get('order.process.email');
    return $config;
  }

  /**
   * Set the plugin configuration.
   */
  public function setConfig($store, $data) {
    $config = $this->config->getEditable('order.process.email');
    $config->set($store, $data)
      ->save();
  }

  /**
   * Process order data.
   */
  public function processOrder(Order $order, $data = []) {
    // The submitted order and checkout data to be processed.
    // $order_data = \Drupal::service('order.controller')->getOrderData($order);
    return TRUE;
  }

}
