<?php

/**
 * @file
 * Contains product.page.inc.
 *
 * Page callback for Product entities.
 */

use Drupal\Core\Render\Element;
use Drupal\Core\Url;

/**
 * Prepares variables for Product templates.
 *
 * Default template: product.html.twig.
 *
 * @param array $variables
 *   An associative array containing:
 *   - elements: An associative array containing the user information and any
 *   - attributes: HTML attributes for the containing element.
 */
function template_preprocess_product(array &$variables) {
  // Helpful $content variable for templates.
  foreach (Element::children($variables['elements']) as $key) {
    $variables['content'][$key] = $variables['elements'][$key];
  }
}

/**
 * Preprocess function for add to cart links.
 */
function template_preprocess_product__add_to_cart(array &$variables) {
  /** @var Drupal\order\Entity\Product $product */
  $product = $variables['elements']['#product'];

  $store = $product->getStore();
  /** @var Drupal\order\Entity\Order $order */
  $order = \Drupal::service('order.controller')->getOrder($store);
  $items = \Drupal::service('order.controller')->getItems($order);
  $added = FALSE;
  foreach ($items as $item) {
    $item_product = $item->get('product')->entity;
    if ($item_product->id() == $product->id()) {
      $added = TRUE;
    }
  }

  $labels = $store->get('label_overrides');
  $add_text = $labels['add_button'];
  $option = [
    'query' => ['quantity' => 1],
  ];

  if ($added == TRUE) {
    $variables['attributes']['class'][] = 'product-added';
    $add_text = $labels['added_button'];
  }

  if ($store->get('use_ajax')) {
    $variables['attributes']['class'][] = 'use-ajax';
  }

  $url = URL::fromRoute('order.addToOrder', ["product" => $product->id()], $option);

  // @todo We need to determine if quantity is presented via a setting on both the store and individual product.
  // @todo do something to add a quantity field.
  $variables['#attached']['library'][] = 'core/drupal.ajax';

  $variables['uri'] = $url->toString();
  $variables['product'] = $product;
  $variables['uuid'] = $product->uuid();
  $variables['quantity'] = 1;
  $variables['add'] = $add_text;

  $variables['#cache']['max-age'] = 0;
}
